==> haskell-hsyaml-aeson-0.2.0.1-180-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsYAML-aeson
version:              0.2.0.1
visibility:           public
id:                   HsYAML-aeson-0.2.0.1-CNax88AhoY87SJVK1EidZj
key:                  HsYAML-aeson-0.2.0.1-CNax88AhoY87SJVK1EidZj
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           hvr@gnu.org, Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  a16376394d739d7da4776e6decf08500
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.2.8/site-local/HsYAML-aeson-0.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HsYAML-aeson-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.1-CNax88AhoY87SJVK1EidZj
depends:
    HsYAML-0.2.1.3-CKDh8C7ORvL33YMNhb0U1W
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 mtl-2.2.2
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD text-1.2.5.0
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-aeson-0.2.0.1-227.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsYAML-aeson
version:              0.2.0.1
visibility:           public
id:                   HsYAML-aeson-0.2.0.1-9YOKvHDuSQwEHVYEMwbsaw
key:                  HsYAML-aeson-0.2.0.1-9YOKvHDuSQwEHVYEMwbsaw
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           hvr@gnu.org, Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  a43cf6f2cff62165350003e0d4632108
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.1-9YOKvHDuSQwEHVYEMwbsaw
depends:
    HsYAML-0.2.1.3-AINukzkI0osDAEAPfv3L1J
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.2.2
    scientific-0.3.7.0-FVWP8DVCKbGBwiSARe0xui text-2.0.2
    unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
